#ifndef __world_h
#define __world_h

@extern int deathmatch;

#endif//__world_h
